# SAP LeanIX Technology Risk and Compliance
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance#overview)
  * [Detailed Guides](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance#detailed-guides)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance#related-resources)


Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.
